"""Auto-generated file, do not edit by hand. 506 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_506 = [NumberFormat(pattern='(\\d{4})(\\d{2})(\\d{2})', format='\\1 \\2 \\3', leading_digits_pattern=['[24-7]|8[3-9]'])]
